@@ -228,6 +228,7 @@ func getinfo(name string) (*terminfo.Terminfo, string, error) {
 	t.Bold = tc.getstr("bold")
 	t.Blink = tc.getstr("blink")
 	t.Dim = tc.getstr("dim")
+	t.Italic = tc.getstr("sitm")
 	t.Reverse = tc.getstr("rev")
 	t.EnterKeypad = tc.getstr("smkx")
 	t.ExitKeypad = tc.getstr("rmkx")
@@ -508,6 +509,7 @@ func dotGoInfo(w io.Writer, terms []*TData) {
 		dotGoAddStr(w, "Underline", t.Underline)
 		dotGoAddStr(w, "Bold", t.Bold)
 		dotGoAddStr(w, "Dim", t.Dim)
+		dotGoAddStr(w, "Italic", t.Italic)
 		dotGoAddStr(w, "Blink", t.Blink)
 		dotGoAddStr(w, "Reverse", t.Reverse)
 		dotGoAddStr(w, "EnterKeypad", t.EnterKeypad)
